This package implements Model II from the `Structure of Growing Social Networks <http://journals.aps.org/pre/abstract/10.1103/PhysRevE.64.046132>`_
 (Jin et al, 2001). It generates a social network, using three processes: 1) random friendships, 2) friends meeting friends, and 3) dissolution. I wrote it to generate a static network structure. I did not write it as a scaffold for dynamic simulations. A java port exists as well, since the Python code is terribly slow. 

See: `https://github.com/jbn/jin_et_al_2001 <https://github.com/jbn/jin_et_al_2001>`_